Class: Net::NTLM::Message
- Inherits:
-
Object
- Object
- Net::NTLM::Message
- Defined in:
- sig/rbs/net-ntlm.rbs
Defined Under Namespace
Classes: Type1
Class Method Summary collapse
Instance Method Summary collapse
- #response ⇒ Net::NTLM::Message
-
#target_name= ⇒ String
writer used by adaptor to set target name when a domain is present.
Class Method Details
.parse ⇒ Net::NTLM::Message
5 |
# File 'sig/rbs/net-ntlm.rbs', line 5
def self.parse: (untyped) -> Net::NTLM::Message
|
Instance Method Details
#response ⇒ Net::NTLM::Message
6 |
# File 'sig/rbs/net-ntlm.rbs', line 6
def response: (?Hash[Symbol, untyped], ?Hash[Symbol, untyped]) -> Net::NTLM::Message
|
#target_name= ⇒ String
writer used by adaptor to set target name when a domain is present
8 |
# File 'sig/rbs/net-ntlm.rbs', line 8
def target_name=: (String) -> String
|